#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 time-compat
version:              1.9.9
visibility:           public
id:                   time-compat-1.9.9-JnaK0SQDbcD10fToPhMLpN
key:                  time-compat-1.9.9-JnaK0SQDbcD10fToPhMLpN
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Ashley Yakeley
homepage:             https://github.com/haskellari/time-compat
synopsis:             Compatibility package for time
description:
    This packages tries to compat as much of @time@ features as possible.

    /TODO:/

    * Difference type @ParseTime@ and @FormatTime@ instances are missing.

    * Formatting varies depending on underlying @time@ version

    * @dayFractionToTimeOfDay@ on extreme values

category:             Time, Compatibility
abi:                  94f3d5d63dca9c3420aa314f87edd069
exposed:              True
exposed-modules:
    Data.Time.Calendar.Compat Data.Time.Calendar.Easter.Compat
    Data.Time.Calendar.Julian.Compat Data.Time.Calendar.Month.Compat
    Data.Time.Calendar.MonthDay.Compat
    Data.Time.Calendar.OrdinalDate.Compat
    Data.Time.Calendar.Quarter.Compat
    Data.Time.Calendar.WeekDate.Compat Data.Time.Clock.Compat
    Data.Time.Clock.POSIX.Compat Data.Time.Clock.System.Compat
    Data.Time.Clock.TAI.Compat Data.Time.Compat Data.Time.Format.Compat
    Data.Time.Format.ISO8601.Compat Data.Time.LocalTime.Compat

hidden-modules:
    Data.Format Data.Time.Calendar.DayPeriod Data.Time.Calendar.Private
    Data.Time.Calendar.Types Data.Time.Orphans

import-dirs:          /usr/lib/ghc-9.6.6/site-local/time-compat-1.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/time-compat-1.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/time-compat-1.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-time-compat
hs-libraries:         HStime-compat-1.9.9-JnaK0SQDbcD10fToPhMLpN
depends:
    base-4.18.2.1 base-orphans-0.9.4-3iXj4pzPicR3XRs5FcfHqK
    deepseq-1.4.8.1 hashable-1.4.7.0-3I1JJMFn7WVBoCbELVuec1
    template-haskell-2.20.0.0 time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-time-compat/html/time-compat.haddock
haddock-html:         /usr/share/doc/haskell-time-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

